@@ -76,7 +76,7 @@ def run(config):
 @cli.command()
 @click.argument('filename', type=click.Path(exists=True))
 @click.option('-v', '--verbose', count=True, help='Verbosity Level (-v,-vv)')
-def get_addresses(filename, verbose, force):
+def get_addresses(filename, verbose):
     set_log_level(verbose)
     people = load_people_from_csv(filename)
     log.info(f"Fetching Address for {len(people)} People")
